@@ -3,7 +3,7 @@ package Specio::Constraint::Role::IsaType;
 use strict;
 use warnings;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use Specio::PartialDump qw( partial_dump );
 use Storable qw( dclone );
@@ -55,7 +55,7 @@ sub _wrap_message_generator {
         };
     }
 
-    my $d = $self->_description;
+    my $d = $self->description;
 
     return sub { $generator->( $d, @_ ) };
 }
@@ -77,7 +77,7 @@ Specio::Constraint::Role::IsaType - Provides a common implementation for Specio:
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 DESCRIPTION
 
@@ -85,8 +85,7 @@ See L<Specio::Constraint::AnyIsa> and L<Specio::Constraint::ObjectIsa> for detai
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Specio>
-(or L<bug-specio@rt.cpan.org|mailto:bug-specio@rt.cpan.org>).
+Bugs may be submitted through L<https://github.com/houseabsolute/Specio/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
