@@ -3,7 +3,7 @@ package Specio::Library::Builtins;
 use strict;
 use warnings;
 
-our $VERSION = '0.28';
+our $VERSION = '0.31';
 
 use parent 'Specio::Exporter';
 
@@ -415,7 +415,7 @@ Specio::Library::Builtins - Implements type constraint objects for Perl's built-
 
 =head1 VERSION
 
-version 0.28
+version 0.31
 
 =head1 DESCRIPTION
 
@@ -510,7 +510,8 @@ dereferencing.
 
 =head2 RegexpRef
 
-Accepts a regex object created by C<qr//>.
+Accepts a regex object created by C<qr//> or an object which overloads
+regex interpolation.
 
 =head2 GlobRef
 
@@ -528,8 +529,7 @@ Accepts any blessed object.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Specio>
-(or L<bug-specio@rt.cpan.org|mailto:bug-specio@rt.cpan.org>).
+Bugs may be submitted through L<https://github.com/houseabsolute/Specio/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
